==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QNoDepthMask.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Disable depth write</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qnodepthmask.html">Qt3DRender::QNoDepthMask</a></code></p>
 */
public class QNoDepthMask extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QNoDepthMask.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qnodepthmask.html#QNoDepthMask">Qt3DRender::QNoDepthMask::<wbr>QNoDepthMask(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QNoDepthMask(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QNoDepthMask instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QNoDepthMask(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QNoDepthMask(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QNoDepthMask instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QNoDepthMask(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QNoDepthMask() {
        this((io.qt.qt3d.core.QNode)null);
    }
}

==> qtjambi-qt3drender-6.7.0-sources.jar: io/qt/qt3d/render/QNoDepthMask.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Disable depth write</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qnodepthmask.html">Qt3DRender::QNoDepthMask</a></code></p>
 */
public class QNoDepthMask extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QNoDepthMask.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qnodepthmask.html#QNoDepthMask">Qt3DRender::QNoDepthMask::<wbr/>QNoDepthMask(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QNoDepthMask(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QNoDepthMask instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QNoDepthMask(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QNoDepthMask(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QNoDepthMask instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QNoDepthMask(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QNoDepthMask() {
        this((io.qt.qt3d.core.QNode)null);
    }
}
